@@ -18,12 +18,13 @@
 # along with Friture.  If not, see <http://www.gnu.org/licenses/>.
 
 from friture.ringbuffer import RingBuffer
+from friture.audiobackend import SAMPLING_RATE
 
 FRAMES_PER_BUFFER = 1024
 
 class AudioBuffer():
-	def __init__(self):
-		self.ringbuffer = RingBuffer()
+	def __init__(self, logger):
+		self.ringbuffer = RingBuffer(logger)
 		self.newpoints = 0
 		self.delay_samples = 0
 
@@ -47,4 +48,7 @@ class AudioBuffer():
 		return data
 
 	def set_delay_ms(self, delay_ms):
-		self.delay_samples = delay_ms*1e-3*44100
+		self.delay_samples = delay_ms*1e-3*SAMPLING_RATE
+
+	def data_indexed(self, start, length):
+		return self.ringbuffer.data_indexed(start, length)
