@@ -24,6 +24,7 @@ from friture.spectrogram import Spectrogram_Widget
 from friture.octavespectrum import OctaveSpectrum_Widget
 from friture.scope import Scope_Widget
 from friture.generator import Generator_Widget
+from friture.delay_estimator import Delay_Estimator_Widget
 from friture.controlbar import ControlBar
 
 class Dock(QtGui.QDockWidget):
@@ -60,6 +61,7 @@ class Dock(QtGui.QDockWidget):
 	def widget_select(self, item):
 		if self.audiowidget is not None:
 		    self.audiowidget.close()
+		    self.audiowidget.deleteLater()
 		
 		self.type = item
 
@@ -70,12 +72,13 @@ class Dock(QtGui.QDockWidget):
 		elif item is 2:
 			self.audiowidget = Spectrum_Widget(self, self.logger)
 		elif item is 3:
-			self.audiowidget = Spectrogram_Widget(self, self.logger)
-			self.audiowidget.timer.start()
+			self.audiowidget = Spectrogram_Widget(self, self.parent.audiobackend, self.logger)
 		elif item is 4:
 			self.audiowidget = OctaveSpectrum_Widget(self, self.logger)
 		elif item is 5:
 			self.audiowidget = Generator_Widget(self, self.parent.audiobackend, self.logger)
+		elif item is 6:
+			self.audiowidget = Delay_Estimator_Widget(self, self.logger)
 		
 		self.audiowidget.set_buffer(self.parent.audiobuffer)
 		
